@@ -243,14 +243,12 @@ md_forex1_fxfupan = function(syb) {
 #' # real data
 #' dtfx_real = md_forex(c('eurusd', 'usdcny', 'usdjpy'), type = 'real')
 #' 
-#' # interactivly choose symbols
-#' dtfx_hist2 = md_forex()
 #' }
 #' 
 #' 
 #' @import data.table 
 #' @export
-md_forex = function(symbol=NULL, type = 'history', date_range = '3y', from=NULL, to=Sys.Date(), print_step=1L, ...) {
+md_forex = function(symbol, type = 'history', date_range = '3y', from=NULL, to=Sys.Date(), print_step=1L, ...) {
     
     # symbol
     syb = tolower(symbol)
@@ -275,6 +273,6 @@ md_forex = function(symbol=NULL, type = 'history', date_range = '3y', from=NULL,
     return(dat_list)
 }
 
-md_forex_symbol = function() {
+md_forex_symbol = function(...) {
     func_forex_symbol()[, c('symbol', 'name'), with = FALSE]
 }
\ No newline at end of file
